Page 165 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 165

Home

    scientific input. By every measure the conference
    represented a signal victory for the foes of scientific
    progress, knowledge, and economic development.

    The truth is that this UN grab for global dictatorship
    is based upon a myth. In 100 years of measuring the net
    change in temperature over the earth no more than one
    half of one degree Centigrade has been recorded. Added
    to the proof of those measurements is the data from Tiros

    II, a temperature-measuring satellite that has orbited the
    earth since 1978. This data shows no significant
    temperature trend, either up or down. Outside of
    instrument-measured variations, records go back as far
    as 1,700 years to show that climate varies naturally
    outside of any man made cause.

    For those who desire more information about this and

    many other vital environmental issues, we recommend
    Dixy Lee Ray's book Environmental Overkill: Whatever
    Happened To Common Sense? published by Regnery
    Gateway, Washington, D. C.

    Another example of a theory based upon propaganda
    and half-truths is ozone depletion. Based upon this
    theory, laws have already been passed by the U. S.
    Congress that will, by 1995, ban the manufacture of
    chlorofluorocarbons (CFCs). This action came about as
    a result of another UN treaty referred to as the "Montreal
    Protocol on Substances that Deplete the Ozone Layer."
    Under the provisions of this treaty, Americans can be
    fined $25,000 per day and imprisoned for five years.

    160

    The Secret Side of History